// **************************************************************************
// ROOT macro: plot_total.c
// Plots the figures of total pair production cross section data. 
// There is one figure (now in png format, it can be modified) per element.
// -	cross section data of EPICS2017 (Z: 1-100) 
// -	cross section data of Livermore (Z: 1-99)   
// -	comparison of cross section data between Livermore and EPICS2017 (Z: 1-99) 
// The generated figures are saved in the corresponding directory:
// -	plots/total/comparison
// -	plots/total/epics2017
// -	plots/total/livermore

// Authors: Zhuxin LI @CENBG,France
// 2019.12.09
// **************************************************************************
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <vector>
#include "TPaveStats.h"
TString sInt(Int_t number)
  {
    stringstream ss;
    ss << number;
	TString ts = ss.str();
    return ts;
  }
TString sDouble(double number)
  {
    stringstream ss;
    TString ts = ss.str();
    return ts;
  }
  
  enum DataToPlot
  {
	  Data2017,
	  Data97
  };
  
int results=0;
string param4 = "";
double par[12];
vector<double> fitPar[9];
double ratio1MaxVec[100] = {0}; // maximal relative difference in region 1, poly1, for EPICS2017
double ratio2MaxVec[100] = {0}; // maximal relative difference in region 2, two parts, poly4
double ratio1MaxVec_g4[100] = {0}; // maximal relative difference in region 1, poly1, for Livermore
double ratio2MaxVec_g4[100] = {0}; // maximal relative difference in region 2, poly4

void ReadData()
{
	for(int i = 0; i<9; i++)
	{
		fitPar[i].reserve(101);
	}
	char fitParamTable[64] = "ScatteringFunctionFitsParamsTable_2014.txt";	        	        
	std::ifstream table(fitParamTable);	
	// double* fitPar[101];
	
	double f0;
	double f1;
	double f2;
	double f3;
	double f4;
	double f5;
	double f6;
	double f7;
	double f8;
	// int Z;
	
	table >>f0>>f1>>f2>>f3>>f4>>f5>>f6>>f7>>f8;	// this is to read the first line 0000
// Do not touch this for loop**************
	for (Int_t z = 1;z<=100;++z)// number of element Z, from 1 to 100
// Do not touch this for loop**************
	{
		
		
		table >>f0>>f1>>f2>>f3>>f4>>f5>>f6>>f7>>f8;	
		
		
		fitPar[0][z] = f0;
		fitPar[1][z] = f1;
		fitPar[2][z] = f2;
		fitPar[3][z] = f3;
		fitPar[4][z] = f4;
		fitPar[5][z] = f5;
		fitPar[6][z] = f6;
		fitPar[7][z] = f7;
		fitPar[8][z]= f8;
		// printf("%.9e %.9e %.9e %.9e %.9e %.9e %.9e %.9e %.9e\n", f0, f1, f2, f3, f4, f5, f6, f7, f8);
	}
	table.close();
	
    
}
// void fit(int z, char* dir, bool intervalsModified, double interval1, double interval2)
// void fit(int z, char* dir1, char* dir2)
// {
	
	// gROOT->Reset();
	// // gStyle->SetOptFit();
		
	// TString S = sInt(z); 
	// TString title;
	
	// // if(data ==Data97) //enum
	// // {
		// // title = "EPDL97 scattering function in log-log for element Z = " + S;
		
	// // }
	// // else if(data ==Data2017)
	// // {
		// // title = "EPICS2017 scattering function in log-log for element Z = " + S;
			
	// // }
	
	
	// Int_t ncols;
	// double q, sf;
	// Int_t loop = 0;
	// char str[64] = "";
	// Int_t num1 = 0;  
	// Int_t num2 = 0;  
	// FILE * fp1 = fopen(dir1,"r");
	
		// while(1)  
		// {	
			// loop++;
			// // if loop = 1 we read the first header line
			// fgets (str, 64, fp1);
			// // cout<<str<<endl;
			// if(loop ==2)
			// {
				// // now loop = 2, we read the second header line, namely the number of points
				// num1 = stoi(str);  
				// cout<<"number of  points:"<<num1<<endl;
				// break;
			// }		
			
		// }
		
		// double x_1[num1-1];	
		// double y_1[num1-1]; 		
		// double errx_1[num1-1];	
		// double erry_1[num1-1]; 
		
		// for(Int_t i = 0;i<num1;++i)
		// {
			// // read one line energy cross section
			// ncols = fscanf(fp1,"%lf %lf",&q,&sf); 
			// // printf("%.9e %.9e\n",q, sf);
			// if(i==0) continue;
			// x_1[i-1]=log10(q*(1e14));   // keep energy				
			// y_1[i-1]=log10(sf);  // keep cross section
			// // printf("%.9e %.9e\n",x_1[i-1],y_1[i-1]);
			// errx_1[i-1] = 0;
			// // erry_1[i-1]	=0.05*y_1[i-1];		
			// erry_1[i-1]	=0.05;		
		// }
		// fclose(fp1);
			
			// // read 2014***********begin	
		// FILE * fp2 = fopen(dir2,"r");
		// loop = 0;
		// while(1)  
		// {	
			// loop++;
			// // if loop = 1 we read the first header line
			// fgets (str, 64, fp2);
			// // cout<<str<<endl;
			// if(loop ==2)
			// {
				// // now loop = 2, we read the second header line, namely the number of points
				// num2 = stoi(str);  
				// cout<<"number of  points:"<<num2<<endl;
				// break;
			// }		
			
		// }
		
		// double x_g4[num2-1];	
		// double y_g4[num2-1]; 		
		
		
		// for(Int_t i = 0;i<num2;++i)
		// {
			// // read one line energy cross section
			// ncols = fscanf(fp2,"%lf %lf",&q,&sf); 
			// // printf("%.9e %.9e\n",q, sf);
			// if(i==0) continue;
			// x_g4[i-1]=log10(q);   // keep energy				
			// y_g4[i-1]=log10(sf);  // keep cross section
			// // printf("%.9e %.9e\n",x_1[i-1],y_1[i-1]);
			
						
		// }
		// fclose(fp2);
	// //read 2014***********end	
		
	
		// TCanvas* mycanvas = new TCanvas(S,"Conversion of electrons and gammas",500, 50, 800, 1000);
		// mycanvas->SetGrid();
	
		
		// mycanvas->Divide(1,3);
		// mycanvas->cd(1);
		// gPad->SetGrid();
		// // gPad->SetLogx();
		// // gPad->SetLogy();
		// gPad->SetBottomMargin(0.15);
		// gPad->SetLeftMargin(0.12);
		
		// double interval1 = 6;
		// double interval3 = log10(fitPar[2][z]);
		// double interval2 = 	0.5*interval1+0.5*interval3;
		// printf("-------------%d Intervals: %.9e %.9e %.9e\n", z, interval1, interval2, interval3);
	
		// bool test1 = true;
		// bool test2 = true;
		
		// for(Int_t i = 0;i<num1-1;++i)
		// {
			
			// if(test1 && (x_1[i]>= interval1))   
			// {
				// erry_1[i] =0.001;
				// erry_1[i-1] =0.001;
				// test1 = false;
				
			// }	

			// if(test2 && (x_1[i]>= interval2))   
			// {
				// erry_1[i] =0.001;
				// erry_1[i-1] =0.001;
				// test2 = false;
			// }

			// if(x_1[i]>= interval3)   
			// {
				// erry_1[i-1] =0.001;
				// break;
			// }			
		// }
		// // double c = 	0.5*interval1+0.5*log10(interval2);	
		// TGraphErrors *graph1 = new TGraphErrors(num1-1,x_1,y_1, errx_1, erry_1);
		
		// TF1 *g1    = new TF1("g1","pol1",x_1[0],interval1);		
		// TF1 *g2    = new TF1("g2","pol4",interval1,interval2);
		// TF1 *g3   = new TF1("g3","pol4",interval2,interval3);
		
		
		
		// // TF1 *g3    = new TF1("g1","pol1",log10(1e10),1e5); 
		// graph1->SetMarkerStyle(4);  // red point
		// graph1->SetMarkerSize(1);
		// graph1->SetMarkerColor(2);
		// // graph1->SetLineWidth(2);
		// graph1->SetLineColor(2);
		// graph1->Fit(g1, "R");
		// graph1->Fit(g2, "R+");
		// graph1->Fit(g3, "R+");
		
		// // graph1->Fit(g3, "R+");	
		
		// g1->GetParameters(&par[0]);
		// g2->GetParameters(&par[2]);
		// g3->GetParameters(&par[7]);
		
		// // cout<<par[0]<<" "<<par[1]<<" "<<par[2]<<" "<<par[3]<<" "<<par[4]<<" "<<par[5]<<" "<<par[6]<<endl;
		// char dataline[200];
		// sprintf(dataline,"{%d, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e},\n", 
					   // z, interval1, interval2, fitPar[2][z], par[0], par[1], 
					   // par[2], par[3], par[4], par[5], par[6],
					   // par[7], par[8], par[9], par[10], par[11]); 
		// param4 = param4 + dataline; //concatenate two header lines with data table
		
		// graph1->Draw("APL");
		
		// graph1->SetTitle(title);
		
		// graph1->GetXaxis()->SetTitle("lg(Momentum transfer (cm^{-1}))");
		// graph1->GetYaxis()->SetTitle("lg(Scattering function)");
		
		// graph1->GetXaxis()->SetTitleSize(0.06);
		// graph1->GetYaxis()->SetTitleSize(0.06);
		
		// graph1->GetXaxis()->SetLabelSize(0.05);
		// graph1->GetYaxis()->SetLabelSize(0.05);
		
		
		// graph1->GetXaxis()->CenterTitle();
		// graph1->GetYaxis()->CenterTitle();
		
		// graph1->GetXaxis()->SetLimits(0,17);
		// // graph1->SetMinimum(1e-1);
		
		// TLegend* leg = new TLegend(.15,.7,.3,.9);
		// leg->SetFillColor(0);	
		// leg->SetTextSize(0.04);	
		
		
		// TString Tnum1 = sInt(num1-1);	
		
		// TString name1 = "EPICS2017 - "+ Tnum1 + " points";		
				
		// leg->AddEntry(graph1,name1);
		// // leg->DrawClone("Same");
		// leg->Draw();
		
		// // // mycanvas->Update();
		// // // auto stats1 = (TPaveStats*)graph1->GetListOfFunctions()->FindObject("stats");
		
		// // // stats1->SetTextColor(kRed);
		// // // stats1->SetX1NDC(0.12); stats1->SetX2NDC(0.32); stats1->SetY1NDC(0.75);
   
    // //******************************************************
		// mycanvas->cd(2);
		// gPad->SetGrid();
		// gPad->SetLogx();
		// // gPad->SetLogy();
		// gPad->SetBottomMargin(0.15);
		// gPad->SetLeftMargin(0.12);
		// // linear values
		// Double_t x_2[num1-1];
		// Double_t y_2[num1-1];
		
		// vector<Double_t> x_3[4];  // initiate 4  vectors for  x values 
		// vector<Double_t> y_3[4];  // initiate 4  vectors for fitted y values 
		// // y_3[0]: region 1
		// // y_3[1]: first of region 2
		// // y_3[2]: second of region 2
		// // y_3[3]: region 3
		// // 
		// // fitted linear values
		// // Double_t y_3[num1-1];
		// Double_t value_fit;
		// Double_t y_fit;
	
		
		// // Double_t R[num1-1];
		// Double_t ratio_fit;
		// vector<Double_t> R[4];  // initiate 4  vectors for fitted ratio 
		// // R[0]: region 1
		// // R[1]: first of region 2
		// // R[2]: second of region 2
		// // R[3]: region 3
		
		// cout<<par[0]<<" "<<par[1]<<" "<<par[2]<<" "<<par[3]<<" "<<par[4]<<" "<<par[5]<<" "<<par[6]<<" "<<par[7]<<" "
		// <<par[8]<<" "<<par[9]<<" "<<par[10]<<" "<<par[11]<<endl;
		// // interval1 = max(interval1,newScatFuncFitParam2_1[z]);
		// double ratio1 = 0; //for first of region 1, poly 1
		// double ratio21 = 0; //for second of region 1, poly 4
		// double ratio22 = 0; //for second of region 2, poly 4
		// for(int i = 0; i<num1-1;i++)
		// // for(int i = 0; i<num1;i++)
		// {
			// static int I = 0;
			// I++;
			// x_2[i] = pow(10,x_1[i]);
			// y_2[i] = pow(10, y_1[i]);
			// // if(x_1[i]<=log10(interval2))
			// if(x_1[i]<=interval3)
			// {
				// // region 1
				// if(x_1[i]<interval1)
				// {
					// value_fit = par[0] + par[1]*x_1[i];
					// y_fit = pow(10,value_fit);
					
					// x_3[0].push_back(x_2[i]);
					// y_3[0].push_back(y_fit);
					
					// if(y_1[i]==value_fit || y_1[i] ==0.)
					// {
						
						// ratio_fit = 0;
					// }
					// else{
						
						// ratio_fit = (y_fit - y_2[i])/y_2[i]*100;
					// }
					// R[0].push_back(ratio_fit);
					// if(abs(ratio_fit)>abs(ratio1)) ratio1 = ratio_fit;
					// // printf("1ssssssss%d, %.9e %.9e %.9e %.9e %.9e\n", i+1, x_1[i], y_1[i], y_2[i], r[i], R[i]);
					// // printf("%d %.10e %.9e %.9e ------------\n", I, x_1[i], y_fit, ratio_fit);
				// }
				// //first of region 2
				// else if (x_1[i]>=interval1 && x_1[i]<interval2)
				// {
					// value_fit = par[2] + par[3]*x_1[i] + par[4]*x_1[i]*x_1[i] + par[5]*x_1[i]*x_1[i]*x_1[i] + par[6]*x_1[i]*x_1[i]*x_1[i]*x_1[i];
					// y_fit = pow(10,value_fit);
					
					// x_3[1].push_back(x_2[i]);
					// y_3[1].push_back(y_fit);
					
					// if(y_1[i]==value_fit || y_1[i] ==0.)
					// {
						
						// ratio_fit = 0;
					// }
					// else{
						
						// ratio_fit = (y_fit - y_2[i])/y_2[i]*100;
					// }
					// R[1].push_back(ratio_fit);
					// if(abs(ratio_fit)>abs(ratio21)) ratio21 = ratio_fit;
					// // printf("2ssssssss%d, %.9e %.9e %.9e %.9e %.9e\n", i+1, x_1[i], y_1[i], y_2[i], r[i], R[i]);
					// // printf("%d %.10e %.9e %.9e ***********\n", I, x_1[i], y_fit, ratio_fit);
				// }
				// // second of region 2
				// else
				// {
					// value_fit = par[7] + par[8]*x_1[i] + par[9]*x_1[i]*x_1[i] + par[10]*x_1[i]*x_1[i]*x_1[i] + par[11]*x_1[i]*x_1[i]*x_1[i]*x_1[i];
					// y_fit = pow(10,value_fit);
					
					// x_3[2].push_back(x_2[i]);
					// y_3[2].push_back(y_fit);
					
					// if(y_1[i]==value_fit || y_1[i] ==0.)
					// {
						
						// ratio_fit = 0;
					// }
					// else{
						
						// ratio_fit = (y_fit - y_2[i])/y_2[i]*100;
					// }
					// R[2].push_back(ratio_fit);
					// if(abs(ratio_fit)>abs(ratio22)) ratio22 = ratio_fit;

				// }
			// }
			// //region 3
			// else
			// {
				
				// x_3[3].push_back(x_2[i]);
				// y_3[3].push_back(z);
				
				// if(y_1[i] == log10(z) || y_1[i] ==0.)
				// {
					
					// ratio_fit = 0;
				// }
				// else{
					
					// ratio_fit = (z - y_2[i])/y_2[i]*100;
				// }
				// R[3].push_back(ratio_fit);
				// // printf("Region 3 %d, %.9e %.9e %.9e\n", i+1, x_2[i], y_2[i], ratio_fit );
			// }
			
		
			
		// }
		// ratio1MaxVec[z-1] = ratio1;		
		// ratio2MaxVec[z-1] = max(abs(ratio21), abs(ratio22));
		
		// // Geant4 fit***********************************************
		// vector<Double_t> x_4[3];  // initiate 3  vectors for  x values 
		// vector<Double_t> y_4[3];  // initiate 3  vectors for fitted y values
		// vector<Double_t> R_4[3];  // initiate 3  vectors for fitted y values
		// Double_t x_5[num2-1];  // linear values
		// Double_t y_5[num2-1];
		// double ratio1_g4 = 0;
		// double ratio2_g4 = 0;
		// for(Int_t i = 0;i<num2-1;++i)
		// {
			// x_5[i] = pow(10, x_g4[i]);
			// y_5[i] = pow(10, y_g4[i]);
			
			// if(x_g4[i] <= interval3)
			// {
				
				// if (x_g4[i] < fitPar[1][z]) 
				// { 
					// value_fit = fitPar[3][z] + fitPar[4][z]*x_g4[i];
					// y_fit = pow(10,value_fit);
					
					// x_4[0].push_back(x_5[i]);
					// y_4[0].push_back(y_fit);
					
					// if(y_g4[i]==value_fit || y_g4[i] ==0.)
					// {
						
						// ratio_fit = 0;
					// }
					// else{
						
						// ratio_fit = (y_fit - y_5[i])/y_5[i]*100;
					// }
					// R_4[0].push_back(ratio_fit);
					// if(abs(ratio_fit)>abs(ratio1_g4)) ratio1_g4 = ratio_fit;
				// }
				// else 
				// {
					// value_fit = fitPar[5][z] + fitPar[6][z]*x_g4[i]+ fitPar[7][z]*x_g4[i]*x_g4[i]+ fitPar[8][z]*x_g4[i]*x_g4[i]*x_g4[i];
					// y_fit = pow(10,value_fit);
					
					// x_4[1].push_back(x_5[i]);
					// y_4[1].push_back(y_fit);
					
					// if(y_g4[i]==value_fit || y_g4[i] ==0.)
					// {
						
						// ratio_fit = 0;
					// }
					// else{
						
						// ratio_fit = (y_fit - y_5[i])/y_5[i]*100;
					// }
					// R_4[1].push_back(ratio_fit);
					// if(abs(ratio_fit)>abs(ratio2_g4)) ratio2_g4 = ratio_fit;
				// }
				
				
			// }
			// else 
			// {
				// x_4[2].push_back(x_5[i]);
				// y_4[2].push_back(z);
				
				// if(y_g4[i] == log10(z) || y_g4[i] ==0.)
				// {
					
					// ratio_fit = 0;
				// }
				// else{
					
					// ratio_fit = (z - y_5[i])/y_5[i]*100;
				// }
				// R_4[2].push_back(ratio_fit);				
					
			// }
			
		// }
		// ratio1MaxVec_g4[z-1] = ratio1_g4;		
		// ratio2MaxVec_g4[z-1] = ratio2_g4;		
		
	// // Geant4 fit***************************end	
		
		// auto mg = new TMultiGraph();
		// TGraph *graph = new TGraph(num1-1,x_2,y_2);
		// // TGraph *fit = new TGraph(num1-1,x_2,y_3);
		// TGraph *fit1 = new TGraph(x_3[0].size(),x_3[0].data(),y_3[0].data());
		// TGraph *fit2 = new TGraph(x_3[1].size(),x_3[1].data(),y_3[1].data());
		// TGraph *fit3 = new TGraph(x_3[2].size(),x_3[2].data(),y_3[2].data());
		// TGraph *fit4 = new TGraph(x_3[3].size(),x_3[3].data(),y_3[3].data());
	
		// TGraph *fit1_g4 = new TGraph(x_4[0].size(),x_4[0].data(),y_4[0].data());
		// TGraph *fit2_g4 = new TGraph(x_4[1].size(),x_4[1].data(),y_4[1].data());
		// TGraph *fit3_g4 = new TGraph(x_4[2].size(),x_4[2].data(),y_4[2].data());
		
		// fit1->SetMarkerStyle(24);  //red point
		// fit1->SetMarkerSize(1.5);
		// fit1->SetMarkerColor(kRed);
		// fit1->SetLineColor(kRed);	
		// // fitting2->Fit("pol6","q");
		// mg->Add(fit1);	
		
		// fit2->SetMarkerStyle(24);  //red point
		// fit2->SetMarkerSize(1.5);
		// fit2->SetMarkerColor(kBlue);
		// fit2->SetLineColor(kBlue);	
		// // fitting2->Fit("pol6","q");
		// mg->Add(fit2);	
		
		
		// fit3->SetMarkerStyle(24);  //red point
		// fit3->SetMarkerSize(1.5);
		// fit3->SetMarkerColor(kTeal+4);
		// fit3->SetLineColor(kTeal+4);	
		// // fitting2->Fit("pol6","q");
		// mg->Add(fit3);	
		
		
		// fit4->SetMarkerStyle(24);  //red point
		// fit4->SetMarkerSize(1.5);
		// fit4->SetMarkerColor(kMagenta);
		// fit4->SetLineColor(kMagenta);	
		// // fitting2->Fit("pol6","q");
		// mg->Add(fit4);
		
		
		// fit1_g4->SetMarkerStyle(22);  //red point
		// fit1_g4->SetMarkerSize(1.3);
		// fit1_g4->SetMarkerColor(kYellow);
		// fit1_g4->SetLineColor(kYellow);	
		// // fitting2->Fit("pol6","q");
		// mg->Add(fit1_g4);	
		
		// fit2_g4->SetMarkerStyle(22);  //red point
		// fit2_g4->SetMarkerSize(1.3);
		// fit2_g4->SetMarkerColor(kMagenta+2);
		// fit2_g4->SetLineColor(kMagenta+2);	
		// // fitting2->Fit("pol6","q");
		// mg->Add(fit2_g4);	
		
		
		// fit3_g4->SetMarkerStyle(22);  //red point
		// fit3_g4->SetMarkerSize(1.3);
		// fit3_g4->SetMarkerColor(kCyan+3);
		// fit3_g4->SetLineColor(kCyan+3);	
		// // fitting2->Fit("pol6","q");
		// mg->Add(fit3_g4);	
		
		
		// graph->SetMarkerStyle(20);  // blue circle
		// graph->SetMarkerSize(0.5);
		// graph->SetMarkerColor(kBlack);
		// // graph->SetLineWidth(kMagenta);
		// graph->SetLineColor(kBlack);	
		// // fitting1->Fit("pol6","q");
		// mg->Add(graph);
		
		// mg->Draw("APL");
	
		// mg->SetTitle("Fitted data VS tabulated scattering function");
		// mg->GetXaxis()->SetTitle("Momentum transfer (cm^{-1})");
		// mg->GetYaxis()->SetTitle("Scattering function");
		
		// mg->GetXaxis()->SetTitleSize(0.05);
		// mg->GetYaxis()->SetTitleSize(0.05);
		// mg->GetXaxis()->SetTitleOffset(1.2);
		
		// mg->GetXaxis()->SetLabelSize(0.05);
		// mg->GetYaxis()->SetLabelSize(0.05);
		
		
		// mg->GetXaxis()->CenterTitle();
		// mg->GetYaxis()->CenterTitle();
		
		// mg->GetXaxis()->SetLimits(1,1e17);
		
		// TLegend* leg1 = new TLegend(.12,.4,.35,.9);
		// leg1->SetFillColor(0);	
		// leg1->SetTextSize(0.04);
		
		// TString Name1 = "Region 1 for present work";
		// TString Name21 = "First part of region 2 for present work";
		// TString Name22 = "Second part of region 2 for present work";
		// TString Name3 = "Region 3 for present work";
		
		// TString Name1_g4 = "Region 1 for Geant4 10.07 version";
		// TString Name2_g4 = "Region 2 for Geant4 10.07 version";
		// TString Name3_g4 = "Region 3 for Geant4 10.07 version";
		
		// TString Name_tab = "Tabulated EPICS2017";
		
				
		// leg1->AddEntry(graph,Name_tab);
		// leg1->AddEntry(fit1,Name1);
		// leg1->AddEntry(fit2,Name21);
		// leg1->AddEntry(fit3,Name22);
		// leg1->AddEntry(fit4,Name3);
		
		// leg1->AddEntry(fit1_g4,Name1_g4);
		// leg1->AddEntry(fit2_g4,Name2_g4);
		// leg1->AddEntry(fit3_g4,Name3_g4);
		
		// leg1->Draw();
		
		// // // TLatex latex;
		// // // latex.SetTextSize(0.04);
		// // // latex.SetTextAlign(22);
		// // // TString equation1 = "lg(y) = par[0] + par[1]*x_1[i];";
		// // // latex.DrawLatexNDC(0.28,0.8, );
	
	
	
// // //*****************************************************
		// mycanvas->cd(3);
		// gPad->SetGrid();
		// gPad->SetLogx();
		// // gPad->SetLogy();
		// gPad->SetBottomMargin(0.15);
		// gPad->SetLeftMargin(0.12);
		
		
		
		// // for(int i = 0; i<num1-1;i++)
		// // for(int i = 0; i<num1;i++)
		// // {
			
			
			// // printf("******%d, %.9e %.9e\n", i+1, x_2[i], R[i]);			
			
			
		// // }
		
		// // TGraph *Ratio = new TGraph(num1-1,x_2,R);
		// TGraph *Ratio1 = new TGraph(x_3[0].size(),x_3[0].data(),R[0].data());
		// TGraph *Ratio2 = new TGraph(x_3[1].size(),x_3[1].data(),R[1].data());
		// TGraph *Ratio3 = new TGraph(x_3[2].size(),x_3[2].data(),R[2].data());
		// TGraph *Ratio4 = new TGraph(x_3[3].size(),x_3[3].data(),R[3].data());
		
		// TGraph *Ratio1_g4 = new TGraph(x_4[0].size(),x_4[0].data(),R_4[0].data());
		// TGraph *Ratio2_g4 = new TGraph(x_4[1].size(),x_4[1].data(),R_4[1].data());
		// TGraph *Ratio3_g4 = new TGraph(x_4[2].size(),x_4[2].data(),R_4[2].data());
		
		// auto mg1 = new TMultiGraph();
		
		// Ratio1->SetMarkerStyle(24);  // blue circle
		// Ratio1->SetMarkerSize(1.5);
		// Ratio1->SetMarkerColor(kRed);
		// // Ratio1->SetLineWidth(kMagenta);
		// Ratio1->SetLineColor(kRed);	
		// mg1->Add(Ratio1);


		// Ratio2->SetMarkerStyle(24);  // blue circle
		// Ratio2->SetMarkerSize(1.5);
		// Ratio2->SetMarkerColor(kBlue);
		// // Ratio2->SetLineWidth(kMagenta);
		// Ratio2->SetLineColor(kBlue);	
		// mg1->Add(Ratio2);

		
		// Ratio3->SetMarkerStyle(24);  // blue circle
		// Ratio3->SetMarkerSize(1.5);
		// Ratio3->SetMarkerColor(kTeal+4);
		// // Ratio3->SetLineWidth(kMagenta);
		// Ratio3->SetLineColor(kTeal+4);	
		// mg1->Add(Ratio3);

		// Ratio4->SetMarkerStyle(24);  // blue circle
		// Ratio4->SetMarkerSize(1.5);
		// Ratio4->SetMarkerColor(kMagenta);
		// // Ratio4->SetLineWidth(kMagenta);
		// Ratio4->SetLineColor(kMagenta);	
		// mg1->Add(Ratio4);
		
		
		// Ratio1_g4->SetMarkerStyle(22);  //red point
		// Ratio1_g4->SetMarkerSize(1.3);
		// Ratio1_g4->SetMarkerColor(kYellow);
		// Ratio1_g4->SetLineColor(kYellow);	
		// // fitting2->Fit("pol6","q");
		// mg1->Add(Ratio1_g4);	
		
		// Ratio2_g4->SetMarkerStyle(22);  //red point
		// Ratio2_g4->SetMarkerSize(1.3);
		// Ratio2_g4->SetMarkerColor(kMagenta+2);
		// Ratio2_g4->SetLineColor(kMagenta+2);	
		// // fitting2->Fit("pol6","q");
		// mg1->Add(Ratio2_g4);	
		
		
		// Ratio3_g4->SetMarkerStyle(22);  //red point
		// Ratio3_g4->SetMarkerSize(1.3);
		// Ratio3_g4->SetMarkerColor(kCyan+3);
		// Ratio3_g4->SetLineColor(kCyan+3);	
		// // fitting2->Fit("pol6","q");
		// mg1->Add(Ratio3_g4);
		
		// TString title1 = "Relative difference of fitted data compared to tabulated scattering function for element Z = " + S;
		// mg1->SetTitle(title1);
		
		// mg1->Draw("APL");
		// mg1->GetXaxis()->SetTitle("Momentum transfer (cm^{-1})");
		// mg1->GetYaxis()->SetTitle("Relative difference (%)");
		
		// mg1->GetXaxis()->SetTitleSize(0.05);
		// mg1->GetYaxis()->SetTitleSize(0.05);
		// // Ratio->GetXaxis()->SetTitleOffset(1.2);
		
		// mg1->GetXaxis()->SetLabelSize(0.05);
		// mg1->GetYaxis()->SetLabelSize(0.05);
		
		
		// mg1->GetXaxis()->CenterTitle();
		// mg1->GetYaxis()->CenterTitle();
		// mg1->GetXaxis()->SetLimits(1,1e17);
	
	
		// TLegend* leg2 = new TLegend(.12,.4,.35,.9);
		// leg2->SetFillColor(0);	
		// leg2->SetTextSize(0.04);
		
		
		
				
		// leg2->AddEntry(Ratio1,Name1);
		// leg2->AddEntry(Ratio2,Name21);
		// leg2->AddEntry(Ratio3,Name22);
		// leg2->AddEntry(Ratio4,Name3);
		
		// leg2->AddEntry(Ratio1_g4,Name1_g4);
		// leg2->AddEntry(Ratio2_g4,Name2_g4);
		// leg2->AddEntry(Ratio3_g4,Name3_g4);
		
		// leg2->Draw();
		
	
		// mycanvas->Print("plots/fitScatteringFunction/fit-sf-"+ S +".png");
		
		
		// // mycanvas->Close();
		// // // mycanvas->Modified();
		// delete mycanvas;
		// mycanvas = NULL;
// }

// for the publication

void fit_2(int z, char* dir1, char* dir2)
{
	
	gROOT->Reset();
	// gStyle->SetOptFit();
		
	TString S = sInt(z); 
	TString title;
	
	// if(data ==Data97) //enum
	// {
		// title = "EPDL97 scattering function in log-log for element Z = " + S;
		
	// }
	// else if(data ==Data2017)
	// {
		// title = "EPICS2017 scattering function in log-log for element Z = " + S;
			
	// }
	
	
	Int_t ncols;
	double q, sf;
	Int_t loop = 0;
	char str[64] = "";
	Int_t num1 = 0;  
	Int_t num2 = 0;  
	FILE * fp1 = fopen(dir1,"r");
	
		while(1)  
		{	
			loop++;
			// if loop = 1 we read the first header line
			fgets (str, 64, fp1);
			// cout<<str<<endl;
			if(loop ==2)
			{
				// now loop = 2, we read the second header line, namely the number of points
				num1 = stoi(str);  
				cout<<"number of  points:"<<num1<<endl;
				break;
			}		
			
		}
		
		double x_1[num1-1];	
		double y_1[num1-1]; 		
		double errx_1[num1-1];	
		double erry_1[num1-1]; 
		
		for(Int_t i = 0;i<num1;++i)
		{
			// read one line energy cross section
			ncols = fscanf(fp1,"%lf %lf",&q,&sf); 
			// printf("%.9e %.9e\n",q, sf);
			if(i==0) continue;
			x_1[i-1]=log10(q*(1e14));   // keep energy				
			y_1[i-1]=log10(sf);  // keep cross section
			// printf("%.9e %.9e\n",x_1[i-1],y_1[i-1]);
			errx_1[i-1] = 0;
			// erry_1[i-1]	=0.05*y_1[i-1];		
			erry_1[i-1]	=0.05;		
		}
		fclose(fp1);
			
			// read 2014***********begin	
		FILE * fp2 = fopen(dir2,"r");
		loop = 0;
		while(1)  
		{	
			loop++;
			// if loop = 1 we read the first header line
			fgets (str, 64, fp2);
			// cout<<str<<endl;
			if(loop ==2)
			{
				// now loop = 2, we read the second header line, namely the number of points
				num2 = stoi(str);  
				cout<<"number of  points:"<<num2<<endl;
				break;
			}		
			
		}
		
		double x_g4[num2-1];	
		double y_g4[num2-1]; 		
		
		
		for(Int_t i = 0;i<num2;++i)
		{
			// read one line energy cross section
			ncols = fscanf(fp2,"%lf %lf",&q,&sf); 
			// printf("%.9e %.9e\n",q, sf);
			if(i==0) continue;
			x_g4[i-1]=log10(q);   // keep energy				
			y_g4[i-1]=log10(sf);  // keep cross section
			// printf("%.9e %.9e\n",x_1[i-1],y_1[i-1]);
			
						
		}
		fclose(fp2);
	//read 2014***********end	
		
	
		TCanvas* mycanvas = new TCanvas(S,"Conversion of electrons and gammas",500, 50, 800, 400);
		mycanvas->SetGrid();
	
		
		// mycanvas->Divide(1,3);
		// mycanvas->cd(1);
		gPad->SetGrid();
		gPad->SetLogx();
		// gPad->SetLogy();
		gPad->SetBottomMargin(0.15);
		gPad->SetLeftMargin(0.15);
		
		double interval1 = 6;
		double interval3 = log10(fitPar[2][z]);
		double interval2 = 	0.5*interval1+0.5*interval3;
		printf("-------------%d Intervals: %.9e %.9e %.9e\n", z, interval1, interval2, interval3);
	
		bool test1 = true;
		bool test2 = true;
		
		for(Int_t i = 0;i<num1-1;++i)
		{
			
			if(test1 && (x_1[i]>= interval1))   
			{
				erry_1[i] =0.001;
				erry_1[i-1] =0.001;
				test1 = false;
				
			}	

			if(test2 && (x_1[i]>= interval2))   
			{
				erry_1[i] =0.001;
				erry_1[i-1] =0.001;
				test2 = false;
			}

			if(x_1[i]>= interval3)   
			{
				erry_1[i-1] =0.001;
				break;
			}			
		}
		// double c = 	0.5*interval1+0.5*log10(interval2);	
		TGraphErrors *graph1 = new TGraphErrors(num1-1,x_1,y_1, errx_1, erry_1);
		
		TF1 *g1    = new TF1("g1","pol1",x_1[0],interval1);		
		TF1 *g2    = new TF1("g2","pol4",interval1,interval2);
		TF1 *g3   = new TF1("g3","pol4",interval2,interval3);
		
		
		
		// TF1 *g3    = new TF1("g1","pol1",log10(1e10),1e5); 
		graph1->SetMarkerStyle(4);  // red point
		graph1->SetMarkerSize(1);
		graph1->SetMarkerColor(2);
		// graph1->SetLineWidth(2);
		graph1->SetLineColor(2);
		graph1->Fit(g1, "R");
		graph1->Fit(g2, "R+");
		graph1->Fit(g3, "R+");
		
		// graph1->Fit(g3, "R+");	
		
		g1->GetParameters(&par[0]);
		g2->GetParameters(&par[2]);
		g3->GetParameters(&par[7]);
		
		// cout<<par[0]<<" "<<par[1]<<" "<<par[2]<<" "<<par[3]<<" "<<par[4]<<" "<<par[5]<<" "<<par[6]<<endl;
		char dataline[200];
		sprintf(dataline,"{%d, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e, %.9e},\n", 
					   z, interval1, interval2, fitPar[2][z], par[0], par[1], 
					   par[2], par[3], par[4], par[5], par[6],
					   par[7], par[8], par[9], par[10], par[11]); 
		param4 = param4 + dataline; //concatenate two header lines with data table
		
		// graph1->Draw("APL");
		
	
		
				
				
		
		
		// // mycanvas->Update();
		// // auto stats1 = (TPaveStats*)graph1->GetListOfFunctions()->FindObject("stats");
		
		// // stats1->SetTextColor(kRed);
		// // stats1->SetX1NDC(0.12); stats1->SetX2NDC(0.32); stats1->SetY1NDC(0.75);
   
    //******************************************************
		
		// linear values
		Double_t x_2[num1-1];  // for EPICS2017
		Double_t y_2[num1-1];
		
		vector<Double_t> x_3[4];  // initiate 4  vectors for  x values 
		vector<Double_t> y_3[4];  // initiate 4  vectors for fitted y values 
		// y_3[0]: region 1
		// y_3[1]: first of region 2
		// y_3[2]: second of region 2
		// y_3[3]: region 3
		// 
		// fitted linear values
		// Double_t y_3[num1-1];
		Double_t value_fit;
		Double_t y_fit;
	
		
		// Double_t R[num1-1];
		Double_t ratio_fit;
		vector<Double_t> R[4];  // initiate 4  vectors for fitted ratio 
		// R[0]: region 1
		// R[1]: first of region 2
		// R[2]: second of region 2
		// R[3]: region 3
		
		cout<<par[0]<<" "<<par[1]<<" "<<par[2]<<" "<<par[3]<<" "<<par[4]<<" "<<par[5]<<" "<<par[6]<<" "<<par[7]<<" "
		<<par[8]<<" "<<par[9]<<" "<<par[10]<<" "<<par[11]<<endl;
		// interval1 = max(interval1,newScatFuncFitParam2_1[z]);
		double ratio1 = 0; //for first of region 1, poly 1
		double ratio21 = 0; //for second of region 1, poly 4
		double ratio22 = 0; //for second of region 2, poly 4
		for(int i = 0; i<num1-1;i++)
		// for(int i = 0; i<num1;i++)
		{
			static int I = 0;
			I++;
			x_2[i] = pow(10,x_1[i]);
			y_2[i] = pow(10,y_1[i]); // linear values tabulation of EPICS2017
			// if(x_1[i]<=log10(interval2))
			if(x_1[i]<=interval3)
			{
				// region 1
				if(x_1[i]<interval1)
				{
					value_fit = par[0] + par[1]*x_1[i];
					y_fit = pow(10,value_fit);
					
					x_3[0].push_back(x_2[i]);
					y_3[0].push_back(y_fit);
					
					if(y_1[i]==value_fit || y_1[i] ==0.)
					{
						
						ratio_fit = 0;
					}
					else{
						
						ratio_fit = (y_fit - y_2[i])/y_2[i]*100;
					}
					R[0].push_back(ratio_fit);
					if(abs(ratio_fit)>abs(ratio1)) ratio1 = ratio_fit;
					// printf("1ssssssss%d, %.9e %.9e %.9e %.9e %.9e\n", i+1, x_1[i], y_1[i], y_2[i], r[i], R[i]);
					// printf("%d %.10e %.9e %.9e ------------\n", I, x_1[i], y_fit, ratio_fit);
				}
				//first of region 2
				else if (x_1[i]>=interval1 && x_1[i]<interval2)
				{
					value_fit = par[2] + par[3]*x_1[i] + par[4]*x_1[i]*x_1[i] + par[5]*x_1[i]*x_1[i]*x_1[i] + par[6]*x_1[i]*x_1[i]*x_1[i]*x_1[i];
					y_fit = pow(10,value_fit);
					
					x_3[1].push_back(x_2[i]);
					y_3[1].push_back(y_fit);
					
					if(y_1[i]==value_fit || y_1[i] ==0.)
					{
						
						ratio_fit = 0;
					}
					else{
						
						ratio_fit = (y_fit - y_2[i])/y_2[i]*100;
					}
					R[1].push_back(ratio_fit);
					if(abs(ratio_fit)>abs(ratio21)) ratio21 = ratio_fit;
					// printf("2ssssssss%d, %.9e %.9e %.9e %.9e %.9e\n", i+1, x_1[i], y_1[i], y_2[i], r[i], R[i]);
					// printf("%d %.10e %.9e %.9e ***********\n", I, x_1[i], y_fit, ratio_fit);
				}
				// second of region 2
				else
				{
					value_fit = par[7] + par[8]*x_1[i] + par[9]*x_1[i]*x_1[i] + par[10]*x_1[i]*x_1[i]*x_1[i] + par[11]*x_1[i]*x_1[i]*x_1[i]*x_1[i];
					y_fit = pow(10,value_fit);
					
					x_3[2].push_back(x_2[i]);
					y_3[2].push_back(y_fit);
					
					if(y_1[i]==value_fit || y_1[i] ==0.)
					{
						
						ratio_fit = 0;
					}
					else{
						
						ratio_fit = (y_fit - y_2[i])/y_2[i]*100;
					}
					R[2].push_back(ratio_fit);
					if(abs(ratio_fit)>abs(ratio22)) ratio22 = ratio_fit;

				}
			}
			//region 3
			else
			{
				
				x_3[3].push_back(x_2[i]);
				y_3[3].push_back(z);
				
				if(y_1[i] == log10(z) || y_1[i] ==0.)
				{
					
					ratio_fit = 0;
				}
				else{
					
					ratio_fit = (z - y_2[i])/y_2[i]*100;
				}
				R[3].push_back(ratio_fit);
				// printf("Region 3 %d, %.9e %.9e %.9e\n", i+1, x_2[i], y_2[i], ratio_fit );
			}
			
		
			
		}
		ratio1MaxVec[z-1] = ratio1;		
		ratio2MaxVec[z-1] = max(abs(ratio21), abs(ratio22));
		
		// Geant4 fit***********************************************begin
		vector<Double_t> x_4[3];  // initiate 3  vectors for  x values 
		vector<Double_t> y_4[3];  // initiate 3  vectors for fitted y values
		vector<Double_t> R_4[3];  // initiate 3  vectors for fitted y values
		Double_t x_5[num2-1];  // linear values, tabulation of EPDL2014
		Double_t y_5[num2-1];
		double ratio1_g4 = 0;
		double ratio2_g4 = 0;
		for(Int_t i = 0;i<num2-1;++i)
		{
			x_5[i] = pow(10, x_g4[i]);
			y_5[i] = pow(10, y_g4[i]);
			
			if(x_g4[i] <= interval3)
			{
				
				if (x_g4[i] < fitPar[1][z]) 
				{ 
					value_fit = fitPar[3][z] + fitPar[4][z]*x_g4[i];
					y_fit = pow(10,value_fit);
					
					x_4[0].push_back(x_5[i]);
					y_4[0].push_back(y_fit);
					
					if(y_g4[i]==value_fit || y_g4[i] ==0.)
					{
						
						ratio_fit = 0;
					}
					else{
						
						ratio_fit = (y_fit - y_5[i])/y_5[i]*100;
					}
					R_4[0].push_back(ratio_fit);
					if(abs(ratio_fit)>abs(ratio1_g4)) ratio1_g4 = ratio_fit;
				}
				else 
				{
					value_fit = fitPar[5][z] + fitPar[6][z]*x_g4[i]+ fitPar[7][z]*x_g4[i]*x_g4[i]+ fitPar[8][z]*x_g4[i]*x_g4[i]*x_g4[i];
					y_fit = pow(10,value_fit);
					
					x_4[1].push_back(x_5[i]);
					y_4[1].push_back(y_fit);
					
					if(y_g4[i]==value_fit || y_g4[i] ==0.)
					{
						
						ratio_fit = 0;
					}
					else{
						
						ratio_fit = (y_fit - y_5[i])/y_5[i]*100;
					}
					R_4[1].push_back(ratio_fit);
					if(abs(ratio_fit)>abs(ratio2_g4)) ratio2_g4 = ratio_fit;
				}
				
				
			}
			else 
			{
				x_4[2].push_back(x_5[i]);
				y_4[2].push_back(z);
				
				if(y_g4[i] == log10(z) || y_g4[i] ==0.)
				{
					
					ratio_fit = 0;
				}
				else{
					
					ratio_fit = (z - y_5[i])/y_5[i]*100;
				}
				R_4[2].push_back(ratio_fit);				
					
			}
			
		}
		ratio1MaxVec_g4[z-1] = ratio1_g4;		
		ratio2MaxVec_g4[z-1] = ratio2_g4;		
		
	// Geant4 fit***************************end	
		
		auto mg = new TMultiGraph();
		TGraph *graph = new TGraph(num1-1,x_2,y_2);
		// TGraph *fit = new TGraph(num1-1,x_2,y_3);
		TGraph *fit1 = new TGraph(x_3[0].size(),x_3[0].data(),y_3[0].data());
		TGraph *fit2 = new TGraph(x_3[1].size(),x_3[1].data(),y_3[1].data());
		TGraph *fit3 = new TGraph(x_3[2].size(),x_3[2].data(),y_3[2].data());
		TGraph *fit4 = new TGraph(x_3[3].size(),x_3[3].data(),y_3[3].data());
	
		TGraph *fit1_g4 = new TGraph(x_4[0].size(),x_4[0].data(),y_4[0].data());
		TGraph *fit2_g4 = new TGraph(x_4[1].size(),x_4[1].data(),y_4[1].data());
		TGraph *fit3_g4 = new TGraph(x_4[2].size(),x_4[2].data(),y_4[2].data());
		
		fit1->SetMarkerStyle(24);  //red point
		fit1->SetMarkerSize(1.5);
		fit1->SetMarkerColor(kRed);
		fit1->SetLineColor(kRed);	
		// fitting2->Fit("pol6","q");
		mg->Add(fit1);	
		
		fit2->SetMarkerStyle(24);  //red point
		fit2->SetMarkerSize(1.5);
		fit2->SetMarkerColor(kBlue);
		fit2->SetLineColor(kBlue);	
		// fitting2->Fit("pol6","q");
		mg->Add(fit2);	
		
		
		fit3->SetMarkerStyle(24);  //red point
		fit3->SetMarkerSize(1.5);
		fit3->SetMarkerColor(kTeal+4);
		fit3->SetLineColor(kTeal+4);	
		// fitting2->Fit("pol6","q");
		mg->Add(fit3);	
		
		
		fit4->SetMarkerStyle(24);  //red point
		fit4->SetMarkerSize(1.5);
		fit4->SetMarkerColor(kMagenta);
		fit4->SetLineColor(kMagenta);	
		// fitting2->Fit("pol6","q");
		mg->Add(fit4);
		
		
		fit1_g4->SetMarkerStyle(22);  //red point
		fit1_g4->SetMarkerSize(1.3);
		fit1_g4->SetMarkerColor(kYellow);
		fit1_g4->SetLineColor(kYellow);	
		// fitting2->Fit("pol6","q");
		mg->Add(fit1_g4);	
		
		fit2_g4->SetMarkerStyle(22);  //red point
		fit2_g4->SetMarkerSize(1.3);
		fit2_g4->SetMarkerColor(kMagenta+2);
		fit2_g4->SetLineColor(kMagenta+2);	
		// fitting2->Fit("pol6","q");
		mg->Add(fit2_g4);	
		
		
		fit3_g4->SetMarkerStyle(22);  //red point
		fit3_g4->SetMarkerSize(1.3);
		fit3_g4->SetMarkerColor(kCyan+3);
		fit3_g4->SetLineColor(kCyan+3);	
		// fitting2->Fit("pol6","q");
		mg->Add(fit3_g4);	
		
		
		graph->SetMarkerStyle(20);  // blue circle
		graph->SetMarkerSize(0.5);
		graph->SetMarkerColor(kBlack);
		// graph->SetLineWidth(kMagenta);
		graph->SetLineColor(kBlack);	
		// fitting1->Fit("pol6","q");
		mg->Add(graph);
		
		// mg->Draw("APL");
	
		mg->SetTitle("Fitted data VS tabulated scattering function");
		mg->GetXaxis()->SetTitle("Momentum transfer (cm^{-1})");
		mg->GetYaxis()->SetTitle("Scattering function");
		
		mg->GetXaxis()->SetTitleSize(0.05);
		mg->GetYaxis()->SetTitleSize(0.05);
		mg->GetXaxis()->SetTitleOffset(1.2);
		
		mg->GetXaxis()->SetLabelSize(0.05);
		mg->GetYaxis()->SetLabelSize(0.05);
		
		
		mg->GetXaxis()->CenterTitle();
		mg->GetYaxis()->CenterTitle();
		
		mg->GetXaxis()->SetLimits(1,1e17);
		
		TLegend* leg1 = new TLegend(.12,.4,.35,.9);
		leg1->SetFillColor(0);	
		leg1->SetTextSize(0.04);
		
		TString Name1 = "Region 1 for present work";
		TString Name21 = "First part of region 2 for present work";
		TString Name22 = "Second part of region 2 for present work";
		TString Name3 = "Region 3 for present work";
		
		TString Name1_g4 = "Region 1 for Geant4 10.07 version";
		TString Name2_g4 = "Region 2 for Geant4 10.07 version";
		TString Name3_g4 = "Region 3 for Geant4 10.07 version";
		
		TString Name_tab = "Tabulated EPICS2017";
		
				
		leg1->AddEntry(graph,Name_tab);
		leg1->AddEntry(fit1,Name1);
		leg1->AddEntry(fit2,Name21);
		leg1->AddEntry(fit3,Name22);
		leg1->AddEntry(fit4,Name3);
		
		leg1->AddEntry(fit1_g4,Name1_g4);
		leg1->AddEntry(fit2_g4,Name2_g4);
		leg1->AddEntry(fit3_g4,Name3_g4);
		
		leg1->Draw();
		
		// // TLatex latex;
		// // latex.SetTextSize(0.04);
		// // latex.SetTextAlign(22);
		// // TString equation1 = "lg(y) = par[0] + par[1]*x_1[i];";
		// // latex.DrawLatexNDC(0.28,0.8, );
	
	
	
// //*****************************************************
		// mycanvas->cd(3);
		// gPad->SetGrid();
		// gPad->SetLogx();
		// // gPad->SetLogy();
		// gPad->SetBottomMargin(0.15);
		// gPad->SetLeftMargin(0.12);
		
		
		
		// for(int i = 0; i<num1-1;i++)
		// for(int i = 0; i<num1;i++)
		// {
			
			
			// printf("******%d, %.9e %.9e\n", i+1, x_2[i], R[i]);			
			
			
		// }
		
		// TGraph *Ratio = new TGraph(num1-1,x_2,R);
		TGraph *Ratio1 = new TGraph(x_3[0].size(),x_3[0].data(),R[0].data());
		TGraph *Ratio2 = new TGraph(x_3[1].size(),x_3[1].data(),R[1].data());
		TGraph *Ratio3 = new TGraph(x_3[2].size(),x_3[2].data(),R[2].data());
		TGraph *Ratio4 = new TGraph(x_3[3].size(),x_3[3].data(),R[3].data());
		
		TGraph *Ratio1_g4 = new TGraph(x_4[0].size(),x_4[0].data(),R_4[0].data());
		TGraph *Ratio2_g4 = new TGraph(x_4[1].size(),x_4[1].data(),R_4[1].data());
		TGraph *Ratio3_g4 = new TGraph(x_4[2].size(),x_4[2].data(),R_4[2].data());
		
		auto mg1 = new TMultiGraph();
		
		double fontSize = 1.;
		Ratio1->SetMarkerStyle(24);  // blue circle
		Ratio1->SetMarkerSize(fontSize);
		Ratio1->SetMarkerColor(kRed);
		// Ratio1->SetLineWidth(kMagenta);
		Ratio1->SetLineColor(kRed);	
		mg1->Add(Ratio1);


		Ratio2->SetMarkerStyle(24);  // blue circle
		Ratio2->SetMarkerSize(fontSize);
		Ratio2->SetMarkerColor(kRed);
		// Ratio2->SetLineWidth(kMagenta);
		Ratio2->SetLineColor(kRed);	
		mg1->Add(Ratio2);

		
		Ratio3->SetMarkerStyle(24);  // blue circle
		Ratio3->SetMarkerSize(fontSize);
		Ratio3->SetMarkerColor(kRed);
		// Ratio3->SetLineWidth(kMagenta);
		Ratio3->SetLineColor(kRed);	
		mg1->Add(Ratio3);

		Ratio4->SetMarkerStyle(24);  // blue circle
		Ratio4->SetMarkerSize(fontSize);
		Ratio4->SetMarkerColor(kRed);
		// Ratio4->SetLineWidth(kMagenta);
		Ratio4->SetLineColor(kRed);	
		mg1->Add(Ratio4);
		
		
		Ratio1_g4->SetMarkerStyle(21);  //red point
		Ratio1_g4->SetMarkerSize(0.8);
		Ratio1_g4->SetMarkerColor(kBlue);
		Ratio1_g4->SetLineColor(kBlue);	
		// fitting2->Fit("pol6","q");
		mg1->Add(Ratio1_g4);	
		
		Ratio2_g4->SetMarkerStyle(21);  //red point
		Ratio2_g4->SetMarkerSize(0.8);
		Ratio2_g4->SetMarkerColor(kBlue);
		Ratio2_g4->SetLineColor(kBlue);	
		// fitting2->Fit("pol6","q");
		mg1->Add(Ratio2_g4);	
		
		
		Ratio3_g4->SetMarkerStyle(21);  //red point
		Ratio3_g4->SetMarkerSize(0.8);
		Ratio3_g4->SetMarkerColor(kBlue);
		Ratio3_g4->SetLineColor(kBlue);	
		// fitting2->Fit("pol6","q");
		mg1->Add(Ratio3_g4);
		
		TString title1 = "Relative difference of fitted scattering functions compared to tabulated values for element Z = " + S;
		mg1->SetTitle(title1);
		
		mg1->Draw("APL");
		mg1->GetXaxis()->SetTitle("Momentum transfer q (cm^{-1})");
		mg1->GetYaxis()->SetTitle("Relative difference (%)");
		
		// mg1->GetXaxis()->SetTitleSize(0.05);
		// mg1->GetYaxis()->SetTitleSize(0.05);
		// // Ratio->GetXaxis()->SetTitleOffset(1.2);
		
		// mg1->GetXaxis()->SetLabelSize(0.05);
		// mg1->GetYaxis()->SetLabelSize(0.05);
		
		
		mg1->GetXaxis()->CenterTitle();
		mg1->GetYaxis()->CenterTitle();
		mg1->GetXaxis()->SetLimits(1,1e17);
		
		mg1->GetXaxis()->SetTitleOffset(1.5);
		mg1->GetYaxis()->SetTitleOffset(1.5);
		
		
		TGaxis *axisX = new TGaxis(1,gPad->GetUymax(),
		1e17, gPad->GetUymax(),
		mg1->GetXaxis()->GetXmin(),
		mg1->GetXaxis()->GetXmax(), 510,"GU-");
		
		// axis->SetLineColor(kRed);
		// axis->SetLabelColor(kRed);
		axisX->Draw();
		
		
		TGaxis *axisY = new TGaxis(TMath::Power(10, gPad->GetUxmax()),gPad->GetUymin(),
		TMath::Power(10, gPad->GetUxmax()), gPad->GetUymax(),
		mg1->GetYaxis()->GetXmin(),
		mg1->GetYaxis()->GetXmax(), 510,"U+");
		// axis->SetLineColor(kRed);
		// axis->SetLabelColor(kRed);
		axisY->Draw();
	
	
		// TLegend* leg2 = new TLegend(.12,.4,.35,.9);
		// leg2->SetFillColor(0);	
		// leg2->SetTextSize(0.04);
		
		
		
				
		// leg2->AddEntry(Ratio1,Name1);
		// leg2->AddEntry(Ratio2,Name21);
		// leg2->AddEntry(Ratio3,Name22);
		// leg2->AddEntry(Ratio4,Name3);
		
		// leg2->AddEntry(Ratio1_g4,Name1_g4);
		// leg2->AddEntry(Ratio2_g4,Name2_g4);
		// leg2->AddEntry(Ratio3_g4,Name3_g4);
		
		
		// leg2->Draw();
		
		
		TLegend* leg = new TLegend(.15,.7,.35,.9);
		leg->SetFillColor(0);	
		// leg->SetTextSize(0.04);
		
		
			
		
		TString name1 = "Geant4 11.0";
		TString name2 = "Geant4 10.6";	
		
		leg->AddEntry(Ratio1,name1);
		leg->AddEntry(Ratio1_g4,name2);
		//leg->DrawClone("Same");
		leg->Draw();
		
		
	
		mycanvas->Print("plots/fitScatteringFunction_ForPublication/fit-sf-"+ S +".png");
		
		
		mycanvas->Close();
		// // mycanvas->Modified();
		// delete mycanvas;
		// mycanvas = NULL;
}


void fit_scatteringFunction_Poly1_Poly4_Poly4(){
	// cout<<log10(10)<<endl;
	// cout<<log(10)<<endl;
	// return;
	
	gROOT->Reset();

	gSystem->Exec("mkdir -p plots/fitScatteringFunction/");
	gSystem->Exec("mkdir -p plots/fitScatteringFunction_ForPublication/");
	ReadData();
		
    
	for (Int_t z = 1;z<=100;++z)// number of element Z, from 1 to 100
	{
		
		// if((z != 1) && (z != 13) && (z != 82)) continue;
	
		char path1Format[128] = "epics2017/scatteringFunction/sf-%d.dat"; //prefix of the name of original data file
		char path1[128];
		sprintf(path1,path1Format, z);
		// fit(z, path1, intervalsModified);
		
		char path2Format[128] = "epics2014/scatteringFunction/sf-%d.dat"; //prefix of the name of original data file
		char path2[128];
		sprintf(path2,path2Format, z);
		fit_2(z, path1, path2);
		
			
	}
	
	FILE * output = fopen("ScatteringFunctionTable_Poly1_Poly4_Poly4.dat","w");
	param4 = "{0,              0.,             0.,              0.,              0.,              0.,               0.,              0.,               0.,              0.,               0.,              0.,               0.,              0.,               0.,              0.},\n" + param4;
	fprintf(output, "%s", param4.c_str());
	fclose(output);
	cout<<"results="<<results<<endl;
	
	FILE * output1 = fopen("MaximalDifferenceOfSFFits_2017_2014.dat","w");
	for(int i = 0; i<100; ++i)
	{
		fprintf(output1, "%d %.9e %.9e %.9e %.9e\n", i+1, ratio1MaxVec[i], ratio2MaxVec[i], ratio1MaxVec_g4[i], ratio2MaxVec_g4[i]);
		
	}
	fclose(output1);
}