// **************************************************************************
// ROOT macro: plot_total.c
// Plots the figures of total pair production cross section data. 
// There is one figure (now in png format, it can be modified) per element.
// -	cross section data of EPICS2017 (Z: 1-100) 
// -	cross section data of Livermore (Z: 1-99)   
// -	comparison of cross section data between Livermore and EPICS2017 (Z: 1-99) 
// The generated figures are saved in the corresponding directory:
// -	plots/total/comparison
// -	plots/total/epics2017
// -	plots/total/livermore

// Authors: Zhuxin LI @CENBG,France
// 2019.12.09
// **************************************************************************
TString sInt(Int_t number)
  {
    stringstream ss;
    ss << number;
	TString ts = ss.str();
    return ts;
  }
TString sDouble(Double_t number)
  {
    stringstream ss;
	ss << number;
    TString ts = ss.str();
    return ts;
  }
  
int results=0;


void plotSingle(Int_t z, Int_t plot, char*dir)
{
	gStyle->SetLegendTextSize(0.03);
	TString S = sInt(z);  
	
	TString title;
	
	
	if (plot == 1)
	{
		title = "Energy#timesCS value of EPICS2017 Compton scattering for element Z = " + S;
		
	}
	else if(plot == 2)
	{
		title = "Energy#timesCS value of Livermore Compton scattering for element Z = " + S;
	}
			
		
	Int_t num = 0;  
	Int_t ncols;
	double e, cs;
	Int_t loop = 0;
	char str[64] = "";
	
	
	FILE * fp = fopen(dir,"r");

	while(1)  
	{	
		loop++;
		// if loop = 1 we read the first header line
		fgets (str, 64, fp);
		// cout<<str<<endl;
		if(loop ==2)
		{
			// now loop = 2, we read the second header line, namely the number of points
			num = stoi(str);  
			cout<<"number of compton effect points:"<<num<<endl;
			break;
		}		
		
	}
	TString Tnum = sInt(num);
	
	double x[num];
	// array for total pair production data: cross section		
	double y[num]; 
	
	for(Int_t i = 0;i<num;++i)
	{
		// read one line energy cross section
		ncols = fscanf(fp,"%lf %lf",&e,&cs); 
		x[i]=e;   // keep energy
		y[i]=cs;  // keep cross section
		// printf("%.9e %.9e\n",x_1[i],y_1[i]);
	}
	fclose(fp);
	
	
    TCanvas* mycanvas = new TCanvas(S,"Conversion of electrons and gammas",500, 50, 1000, 600);
		

	//TCanvas* mycanvas=new TCanvas(sz, sz, 200, 10, 1000, 1000);
	mycanvas->SetGrid();
	// mycanvas->SetLeftMargin(0.12);
	//mycanvas->SetFillColor(17);
	gPad->SetLogx();
	
	TGraph *graph = new TGraph(num,x,y);
	//graph->Draw("AC*");
	graph->Draw("APL");
	
	graph->SetMarkerStyle(7);  // red point
	graph->SetMarkerSize(2);
	graph->SetMarkerColor(2);
	//graph->SetLineWidth(2);
	graph->SetLineColor(2);
	
	graph->SetTitle(title);
	
	graph->GetXaxis()->SetTitle("Energy (MeV)");
	graph->GetYaxis()->SetTitle("Energy#timesCS (MeV#timesbarn)");
	
	graph->GetXaxis()->CenterTitle();
	graph->GetYaxis()->CenterTitle();
	
	TLegend* leg = new TLegend(0.1,.7,.42,.9);
	leg->SetFillColor(0);
	// leg->SetTextAlign(22);
	
	
	
	TString name;
	if (plot == 1)
	{
		name = "EPICS2017 - " + Tnum + " points";
		
	}
	else if(plot == 2)
	{
		name = "Livermore - " + Tnum + " points";
	}
	
	
	leg->AddEntry(graph,name);

	leg->Draw();
	
	
	
	
	if (plot == 1)
	{
		mycanvas->Print("plots/epics2017/EPICS2017-ce-cs-" + S + ".png");
		mycanvas->Close();
	}
	else if(plot == 2)
	{
		mycanvas->Print("plots/livermore/Livermore-ce-cs-" + S + ".png");
		mycanvas->Close();
	}
		
		
}

void plotComparison(Int_t z, char*dir1, char*dir2)
{
	
	gROOT->Reset();
		
	TString S = sInt(z); 
	TString title;
	title = "Product Energy #bullet X-section of Compton scattering for element Z = " + S;
		
		
	Int_t num1 = 0;  
	Int_t num2 = 0; 
	
	
	Int_t ncols;
	double e, cs;
	Int_t loop = 0;
	char str[64] = "";
	
	FILE * fp1 = fopen(dir1,"r");
	
		while(1)  
		{	
			loop++;
			// if loop = 1 we read the first header line
			fgets (str, 64, fp1);
			// cout<<str<<endl;
			if(loop ==2)
			{
				// now loop = 2, we read the second header line, namely the number of points
				num1 = stoi(str);  
				// cout<<"number of total pair production points:"<<num1<<endl;
				break;
			}		
			
		}
		
		double x_1[num1];		
		double y_1[num1]; 
		
		for(Int_t i = 0;i<num1;++i)
		{
			// read one line energy cross section
			ncols = fscanf(fp1,"%lf %lf",&e,&cs); 
			x_1[i]=e;   // keep energy
			y_1[i]=cs;  // keep cross section
			// printf("%.9e %.9e\n",x_1[i],y_1[i]);
		}
		fclose(fp1);
		
		FILE * fp2 = fopen(dir2,"r");		
		loop =0;
		
		while(1)
		{	
			loop++;
			// if loop = 1 we read the first header line
			fgets (str, 64, fp2);
			if(loop ==2)
			{
				// now loop = 2, we read the second header line, namely the number of points
				num2 = stoi(str);  
				// cout<<"number of total pair production points:"<<num2<<endl;
				break;
			}		
			
		}
		
		double x_2[num2]; 
		double y_2[num2]; 
		
		for(Int_t i = 0;i<num2;++i)
		{
			// read one line energy cross section
			ncols = fscanf(fp2,"%lf %lf",&e,&cs); 
			x_2[i]=e; // keep energy
			y_2[i]=cs; // keep cross section
			//printf("%.9e %.9e\n",x_2[i],y_2[i]);
		}
		fclose(fp2);
		
		
		TCanvas* mycanvas = new TCanvas(S,"Conversion of electrons and gammas",800, 50, 1200, 1000);
		
		mycanvas->SetGrid();
		mycanvas->Divide(1,2);
		//TPad* pad1 = new TPad("pad1","This is pad1",0.05,0.52,0.95,0.97);
		// TPad* pad1 = new TPad("pad1","This is pad1",0.0,0.4,1.0,1.0);
		// TPad* pad2 = new TPad("pad2","This is pad2",0.0,0.0,1.0,0.4);
		// pad1->Draw();
		// pad2->Draw();
		
		// pad2->cd();
		// TPad* pad21 = new TPad("pad21","First subpad of pad2",0.1,0.0,0.5,1.0);
		// TPad* pad22 = new TPad("pad22","Second subpad of pad2",0.5,0.0,0.9,1.0);
		// pad21->Draw();
		// pad22->Draw();
		
		
		mycanvas->cd(1);
		gPad->SetGrid();
		gPad->SetLogx();
		gPad->SetBottomMargin(0.15);
		gPad->SetLeftMargin(0.12);
		// gPad->SetLeftMargin(0.01);
		//gPad->SetLogy();
					
		TGraph *graph1 = new TGraph(num1,x_1,y_1);
		TGraph *graph2 = new TGraph(num2,x_2,y_2);
		
		//set graph parameters of livermore
		graph2->SetMarkerStyle(4);  //blue circle
		graph2->SetMarkerSize(0.7);
		graph2->SetMarkerColor(4);
		graph2->SetLineColor(4);
		
		graph2->Draw("APL");
	   
		
		//set graph parameters of EPICS2017
		graph1->SetMarkerStyle(7);  // red point
		graph1->SetMarkerSize(2);
		graph1->SetMarkerColor(2);
		//graph1->SetLineWidth(2);
		graph1->SetLineColor(2);	
		graph1->Draw("PL");
				
		graph2->SetTitle(title);
		
		graph2->GetXaxis()->SetTitle("Energy (MeV)");
		graph2->GetYaxis()->SetTitle("Energy #bullet X-section (MeV#bulletbarn)");
		
		graph2->GetXaxis()->SetTitleSize(0.06);
		graph2->GetYaxis()->SetTitleSize(0.06);
		
		graph2->GetXaxis()->SetLabelSize(0.05);
		graph2->GetYaxis()->SetLabelSize(0.05);
		
		
		graph2->GetXaxis()->CenterTitle();
		graph2->GetYaxis()->CenterTitle();
		
		graph2->GetXaxis()->SetLimits(1e-6,100000.);
		
		// graph2->SetMaximum(5e-25); 
		// graph2->SetMinimum(1e-35); 
		
		
		TLegend* leg = new TLegend(.12,.7,.4,.9);
		leg->SetFillColor(0);	
		leg->SetTextSize(0.04);
		
		
		TString Tnum1 = sInt(num1);		
		TString Tnum2 = sInt(num2);	
		
		TString name1 = "EPICS2017 - "+ Tnum1 + " points";
		TString name2 = "Livermore - "+ Tnum2 + " points";		
		
		leg->AddEntry(graph1,name1);
		leg->AddEntry(graph2,name2);
		//leg->DrawClone("Same");
		leg->Draw();
		
		int flag=0;
		double r[num2];  // ratio (%): (EPICS2017-Livermore)/Livermore *100 ;
		
		

		for(Int_t i=num2-1;i>=0;--i)  //Livermore  
		{
			for(Int_t j=num1-1;j>=0;--j) //EPICS2017
			{
				if(x_1[j] == x_2[i]) 
				{				
					//cout<<flag<<"-----"<<x_2[i]<<endl;
					
					if(y_2[i] == y_1[j]) //if(i==0)
					{
						r[i]=0;
						//cout<<r[i]<<endl;
					}
					else 
					{
						r[i] = (y_1[j] - y_2[i])/y_2[i]*100;  //percentage
						//cout<<x_1[j]<<"====="<<r[i]<<endl;
					}
					flag++;
					//cout<<i<<"-----EPICS2017=="<<y_1[j]<<"-----Livermore==" << y_2[i]<<"*****Ratio=="<<r[i]<<endl;
					break;
				
					
				}
			}
		}
		
		if(flag==num2) 
		{
			results++;
			cout<<"flag=="<<flag<<endl;
			cout<<"flag==num2,winnnnnnnnnnnnnn"<<endl;	
		}
		
		
		
		mycanvas->cd(2);
		gPad->SetLogx();
		// gPad->SetTopMargin(0.12);
		gPad->SetBottomMargin(0.15);
		gPad->SetLeftMargin(0.12);
		// gPad->SetBottomMargin(0.15);
		// gPad->SetGrid();
		// gStyle->SetTitleW(0.9);  //per cent of the pad width
		// gStyle->SetTitleH(0.9);
		// gStyle->SetTitleFontSize(0.9);
		
		// // pad21->SetLeftMargin(0.10); //10%
		
		
		char nameRatio[100] = "Relative difference of EPICS2017 compared to Livermore";	
		
		TGraph *ratio = new TGraph(num2,x_2,r);
		ratio->SetTitle(nameRatio);
		ratio->Draw();
		ratio->GetXaxis()->SetTitle("Energy (MeV)");
		ratio->GetYaxis()->SetTitle("Relative Difference (%)");
		
		ratio->GetXaxis()->SetTitleSize(0.06);
		ratio->GetYaxis()->SetTitleSize(0.06);
		
		ratio->GetXaxis()->SetLabelSize(0.05);
		ratio->GetYaxis()->SetLabelSize(0.05);
			
		ratio->GetXaxis()->CenterTitle();
		ratio->GetYaxis()->CenterTitle();
		
		ratio->SetMarkerStyle(8);
		ratio->SetMarkerSize(0.5);
		ratio->SetMarkerColor(2);
		ratio->SetLineColor(2);
		
		TLegend* leg21 =  new TLegend(0.5,0.2,0.9,0.4,"RD = #frac{EPICS2017-Livermore}{Livermore} x 100");
		leg21->SetTextAlign(22);
		leg21->SetFillStyle(0);
		leg21->Draw();
		leg21->SetTextSize(0.05);
		
		
		// TLegend* leg212 =  new TLegend(0.12,0.7,0.3,0.88);
		// TString Tnum4 = sInt(num2);
		// TString name4 = Tnum4 + " points in comparison";		
		// leg212->AddEntry(ratio,name4);
		// leg212->SetTextAlign(22);
		// leg212->SetFillStyle(0);
		// leg212->Draw();
		// leg212->SetTextSize(0.05);
		
		
		
		
		//***********(begin)for the zoomin of the ratio 
		
		
		
		mycanvas->Print("plots/comparison/comparison-ce-cs-"+ S +".png");
		mycanvas->Close();
		
		
}

void plot_csE(){
	
	gROOT->Reset();
	// create the 2 directories if they do not existif
	string dirs[4] = {"plots","livermore","epics2017","comparison"};
	for (Int_t i=0;i<4;++i)
	{
		if(i==0)
		{
			dirs[i] = "mkdir -p "+dirs[i]; 
		// execute the command defined line above
		gSystem->Exec(dirs[i].c_str());
		}
		
		else 
		{
			dirs[i] = "mkdir -p plots/" + dirs[i];
			// execute the command defined line above
			gSystem->Exec(dirs[i].c_str());
		}
		
	}
	
	
		
    
	for (Int_t z = 1;z<=100;++z)// number of element Z, from 1 to 100
	{
		
		
		char path1Format[128] = "epics2017/comp/ce-cs-%d.dat"; //prefix of the name of original data file
		char path1[128];
		
		char path2Format[128] = "livermore/comp/ce-cs-%d.dat"; //prefix of the name of original data file
		char path2[128];
		
		sprintf(path1,path1Format, z);
		sprintf(path2,path2Format, z);
		
		// plotSingle(z,1,path1);
		// plotSingle(z,2,path2);			
		plotComparison(z, path1, path2);
		
			
	}
	cout<<"results="<<results<<endl;
}